colour.models.dataset.pal_secam_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.pal_secam_rgb Module

## Pal/Secam RGB Colourspace

Defines the Pal/Secam RGB colourspace:

- `PAL_SECAM_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.itu.int/dms_pubrec/itu-r/rec/bt/R-REC-BT.470-6-199811-S!!PDF-E.pdf (Last accessed 13 April 2014)

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_PRIMARIES` = array([[ 0.64, 0.33], [ 0.29, 0.6 ], [ 0.15, 0.06]])

  Pal/Secam RGB colourspace primaries.

  PAL_SECAM_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_WHITEPOINT` = (0.31271, 0.32902)

  Pal/Secam RGB colourspace whitepoint.

  PAL_SECAM_RGB_WHITEPOINT : tuple

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_TO_XYZ_MATRIX` = array([[ 0.43054994, 0.34155663, 0.17832197], [ 0.22200231, 0.7066689 , 0.07132879], [ 0.02018203, 0.12955596, 0.93916238]])

  Pal/Secam RGB colourspace to CIE XYZ colourspace matrix.

  PAL_SECAM_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.pal_secam_rgb.` `XYZ_TO_PAL_SECAM_RGB_MATRIX` = array([[ 3.06338864, -1.39340271, -0.47582802], [-0.96922425, 1.87592998, 0.04155423], [ 0.06787259, -0.2288382 , 1.06927151]])

  CIE XYZ colourspace to Pal/Secam RGB colourspace matrix.

  XYZ_TO_PAL_SECAM_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Pal/Secam RGB colourspace.

  PAL_SECAM_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Pal/Secam RGB colourspace to linear.

  PAL_SECAM_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.pal_secam_rgb.` `PAL_SECAM_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24910>

  Pal/Secam RGB colourspace.

  PAL_SECAM_RGB_COLOURSPACE : RGB_Colourspace